@@ -161,7 +161,6 @@ init_status.net <- function(dat) {
   type <- dat$control$type
 
 
-
   # Status ------------------------------------------------------------------
 
   ## Status passed on input network
@@ -244,6 +243,8 @@ init_status.net <- function(dat) {
 
   ## Save out other attr
   dat$attr$active <- rep(1, length(status))
+  dat$attr$entrTime <- rep(1, length(status))
+  dat$attr$exitTime <- rep(NA, length(status))
   if (tea.status == TRUE) {
     dat$nw <- activate.vertex.attribute(dat$nw,
                                         prefix = "testatus",
@@ -260,18 +261,26 @@ init_status.net <- function(dat) {
 
   # If vital=TRUE, infTime is a uniform draw over the duration of infection
   if (dat$param$vital == TRUE && dat$param$di.rate > 0) {
-    infTime[idsInf] <- -rgeom(n = length(idsInf),
-                              prob = dat$param$di.rate)+2
+    infTime[idsInf] <- -rgeom(n = length(idsInf), prob = dat$param$di.rate)+2
   } else {
-    if (dat$control$type == "SI" || dat$param$rec.rate == 0) {
+    if (dat$control$type == "SI" || mean(dat$param$rec.rate) == 0) {
       # infTime a uniform draw over the number of sim time steps
       infTime[idsInf] <- ssample(1:(-dat$control$nsteps + 2),
-                                     length(idsInf),
-                                     replace = TRUE)
+                                     length(idsInf), replace = TRUE)
     } else {
-      infTime[idsInf] <- ssample(1:(-round(1/dat$param$rec.rate) + 2),
-                                 length(idsInf),
-                                 replace = TRUE)
+      if (modes == 1) {
+        infTime[idsInf] <- ssample(1:(-round(1/mean(dat$param$rec.rate)) + 2),
+                                   length(idsInf), replace = TRUE)
+      }
+      if (modes == 2) {
+        infM1 <- which(status == "i" & mode == 1)
+        infTime[infM1] <- ssample(1:(-round(1/mean(dat$param$rec.rate)) + 2),
+                                   length(infM1), replace = TRUE)
+        infM2 <- which(status == "i" & mode == 2)
+        infTime[infM2] <- ssample(1:(-round(1/mean(dat$param$rec.rate.m2)) + 2),
+                                  length(infM2), replace = TRUE)
+
+      }
     }
   }
   dat$attr$infTime <- infTime
@@ -280,7 +289,6 @@ init_status.net <- function(dat) {
 }
 
 
-
 #' @title Persistent ID Initialization
 #'
 #' @description This function initializes the persistent IDs for
