@@ -24,8 +24,8 @@
 #' simulates a specified number of dynamic networks for a specified number of
 #' time steps per simulation. The network statistics in \code{nwstats.formula}
 #' are saved for each time step. Summary statistics for the formation model terms,
-#' as well as dissolution model statistics, are then calculated for access when
-#' printing or plotting the \code{netdx} object.
+#' as well as dissolution model and relational duration statistics, are then
+#' calculated for access when printing or plotting the \code{netdx} object.
 #'
 #' @section Control Arguments:
 #' Models fit with the full STERGM method in \code{netest} (setting \code{edapprox}
@@ -127,7 +127,7 @@ netdx <- function(x,
 
     if (nsims == 1 || ncores == 1) {
       diag.sim <- list()
-      if (verbose == TRUE) {
+      if (verbose == TRUE & nsims > 1) {
         cat("\n  |")
       }
       for (i in 1:nsims) {
@@ -136,11 +136,11 @@ netdx <- function(x,
                                   monitor = nwstats.formula,
                                   nsim = 1,
                                   control = set.control.stergm)
-        if (verbose == TRUE) {
+        if (verbose == TRUE & nsims > 1) {
           cat("*")
         }
       }
-      if (verbose == TRUE) {
+      if (verbose == TRUE & nsims > 1) {
         cat("|")
       }
     } else {
@@ -168,7 +168,7 @@ netdx <- function(x,
 
     if (nsims == 1 || ncores == 1) {
       diag.sim <- list()
-      if (verbose == TRUE) {
+      if (verbose == TRUE & nsims > 1) {
         cat("\n  |")
       }
       for (i in 1:nsims) {
@@ -190,11 +190,11 @@ netdx <- function(x,
                                   monitor = nwstats.formula,
                                   nsim = 1,
                                   control = set.control.stergm)
-        if (verbose == TRUE) {
+        if (verbose == TRUE & nsims > 1) {
           cat("*")
         }
       }
-      if (verbose == TRUE) {
+      if (verbose == TRUE & nsims > 1) {
         cat("|")
       }
     } else {
@@ -254,16 +254,9 @@ netdx <- function(x,
                             names = names(stats.means),
                             stats.means, stats.sd)
 
-  # Which formation terms are offsets?
-  is.offset.term <- grep(pattern = "offset[(]",
-                         strsplit(as.character(formation), "[+]")[[2]])
 
-
-  ## Get stats from for target statistics, removing offsets
-  ts.attr.names <- names(coef.form)
-  if (length(is.offset.term > 0)) {
-    ts.attr.names <- ts.attr.names[-is.offset.term]
-  }
+  ## Get stats from for target statistics
+  ts.attr.names <- x$target.stats.names
   ts.out <- data.frame(names = ts.attr.names,
                        targets = target.stats)
 
@@ -315,16 +308,16 @@ netdx <- function(x,
   # Calculate mean partnership age from edgelist
   if (nsims == 1 || ncores == 1) {
     pages <- list()
-    if (verbose == TRUE) {
+    if (verbose == TRUE & nsims > 1) {
       cat("\n  |")
     }
     for (i in 1:length(diag.sim)) {
       pages[[i]] <- edgelist_meanage(el = sim.df[[i]])
-      if (verbose == TRUE) {
+      if (verbose == TRUE & nsims > 1) {
         cat("*")
       }
     }
-    if (verbose == TRUE) {
+    if (verbose == TRUE & nsims > 1) {
       cat("|")
     }
   } else {
@@ -337,6 +330,55 @@ netdx <- function(x,
   }
 
 
+  ## Dissolution calculations
+
+  if (verbose == TRUE) {
+    cat("\n- Calculating dissolution statistics")
+  }
+
+  ## Create a list of dissolution proportions (i.e. dissolutions/edges)
+  if (nsims == 1 || ncores == 1) {
+    if (verbose == TRUE & nsims > 1) {
+      cat("\n  |")
+    }
+    prop.diss <- list()
+    for (i in 1:length(diag.sim)) {
+      prop.diss[[i]] <- sapply(1:nsteps, function(x) sum(sim.df[[i]]$terminus==x) /
+                                                         sum(sim.df[[i]]$onset < x &
+                                                             sim.df[[i]]$terminus>=x))
+      if (verbose == TRUE & nsims > 1) {
+        cat("*")
+      }
+    }
+    if (verbose == TRUE & nsims > 1) {
+      cat("|")
+    }
+  } else {
+    cluster.size <- min(nsims, ncores)
+    registerDoParallel(cluster.size)
+
+    prop.diss <- foreach(i = 1:nsims) %dopar% {
+       sapply(1:nsteps, function(x) sum(sim.df[[i]]$terminus==x) /
+                                        sum(sim.df[[i]]$onset < x &
+                                            sim.df[[i]]$terminus>=x))
+    }
+  }
+
+  if (verbose == TRUE) {
+    cat("\n ")
+  }
+
+  # Create dissolution table for "dissolution = ~ offset(edges)"
+  if (dissolution == ~offset(edges)) {
+    dissolution.mean <- mean(unlist(prop.diss))
+    dissolution.sd <- sd(unlist(prop.diss))
+    dissolution.expected <- 1/(exp(coef.diss$coef.crude[1]) + 1)
+    stats.table.dissolution <- round(c(target = dissolution.expected,
+                              sim.mean = dissolution.mean,
+                              sim.sd = dissolution.sd), 5)
+  } else {
+    stop('Only ~offset(edges) dissolution models currently supported')
+  }
 
   ## Save output
   out <- list()
@@ -354,8 +396,10 @@ netdx <- function(x,
   out$stats <- stats
   out$stats.table.formation <- stats.table.formation
   out$stats.table.duration <- stats.table.duration
+  out$stats.table.dissolution <- stats.table.dissolution
   out$edgelist <- sim.df
   out$pages <- pages
+  out$prop.diss <- prop.diss
 
   class(out) <- "netdx"
   return(out)
